#include <iostream>
#include "testlib.h"
#include <sstream>
#include <vector>
#include <algorithm>
#include <cassert>
#include <cmath>
#include <queue>
#include <set>

using namespace std;

#define pii pair<int,int>
#define rep(i,n) for(int i=0;i<n;++i)
#define X first
#define Y second


int divisor;

struct point
{
    int x, y;
    int ind;
    
    inline point() { }
    
    inline point(int _x, int _y) {
        x = _x; y = _y;
    }
    
    inline int color () {
        return ind < divisor ? 1 : -1;
    }
};

bool operator<(point a, point b)
{
    return (a.x == b.x && a.y < b.y) || (a.x < b.x);
}

point operator- (point a, point b) {
    return point(a.x-b.x, a.y-b.y);
}

long long cprod(point a, point b) {
    return a.x*b.y - a.y*b.x;
}

long long dprod(point a, point b) {
    return a.x*b.x + a.y*b.y;
}

bool isects (point a, point b, point c, point d) {
    return  (cprod(b-a, c-a) * cprod(b-a, d-a) < 0) &&
            (cprod(d-c, a-c) * cprod(d-c, b-c) < 0);
}

vector<point> read_data() {
    vector<point> p;
    int n = inf.readInteger();
   
    divisor = n;
    n*=2;
    p.resize(n);
    rep(i,n) {
          p[i].x = inf.readInteger();
          p[i].y = inf.readInteger();
          p[i].ind = i;
    }
    return p;
}

vector<pii> read_sol(int n) {
    vector<pii> points;
    set<int> prev;
    set<int> prev1;
    rep(i,n) {
        int a = ouf.readInteger(); 
        int b = ouf.readInteger();
        if (a < 1 || b < 1 || a > n || b > n) {
            quitf(_wa, "WA: point indexes are wrong");
        }
        if (prev.find(a) != prev.end() || prev1.find(b) != prev1.end()) {
            quitf(_wa, "WA: duplicate points");
        }
        prev.insert(a);
        prev1.insert(b);
        points.push_back(make_pair(a, b));
    }

    
    return points;
}

bool check_answer4isections(vector<point>& points, vector<pii> &pairs) {
    int n = pairs.size();
    assert(2*n == points.size());
    vector<int> counts(2*n, 0);
    rep(i,n) {
        rep(j,i) {
           if (isects(points[pairs[i].X-1], points[n+pairs[i].Y-1],
                          points[pairs[j].X-1], points[n+pairs[j].Y-1])) {
               quitf(_wa, "WA: segments intersect");
           }
        }
    }
    return true;
}

int main (int argc, char * argv[]) {
    setName("Task: Points");
    registerTestlibCmd(argc, argv);
    int tests = inf.readInteger();
    rep(i,tests) {
        vector<point> data = read_data();
        vector<pii> pairs = read_sol(data.size()/2);
        check_answer4isections(data, pairs);    
    }
    int extraInOufCount = 0;
    while (!ouf.seekEof())
    {
        ouf.readLong();
        extraInOufCount++;
    }
    if (extraInOufCount > 0)
        quitf(_wa, "Output contains longer sequence");
      quitf(_ok, "OK: everything is fine?");
    return 0;
}
